==> jc-1.4.0.tar.gz: javax/swing/event/MenuEvent.h <==
// public class javax.swing.event.MenuEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class af163240253878eb javax_swing_event_MenuEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_MenuEvent_H_
#define _JC_javax_swing_event_MenuEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_swing_event_MenuEvent$sub_refs	_jc_javax_swing_event_MenuEvent$sub_refs;
typedef struct _jc_javax_swing_event_MenuEvent$sub_nonrefs	_jc_javax_swing_event_MenuEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_MenuEvent$refs	_jc_javax_swing_event_MenuEvent$refs;
typedef struct _jc_javax_swing_event_MenuEvent$nonrefs	_jc_javax_swing_event_MenuEvent$nonrefs;
typedef struct _jc_javax_swing_event_MenuEvent$object	_jc_javax_swing_event_MenuEvent$object;

typedef const struct _jc_javax_swing_event_MenuEvent$vmethods	_jc_javax_swing_event_MenuEvent$vmethods;
typedef const struct _jc_javax_swing_event_MenuEvent$vtable	_jc_javax_swing_event_MenuEvent$vtable;
typedef const struct _jc_javax_swing_event_MenuEvent$vtype	_jc_javax_swing_event_MenuEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_MenuEvent$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_javax_swing_event_MenuEvent$object *, struct _jc_java_lang_Object$object *);

// Virtual methods structure
struct _jc_javax_swing_event_MenuEvent$vmethods {
};

// Vtable
struct _jc_javax_swing_event_MenuEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_MenuEvent$vmethods	javax_swing_event_MenuEvent;
};

// Vtype
struct _jc_javax_swing_event_MenuEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_MenuEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_MenuEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_MenuEvent$refs {
    _jc_javax_swing_event_MenuEvent$sub_refs	javax_swing_event_MenuEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_MenuEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_MenuEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_MenuEvent$sub_nonrefs	javax_swing_event_MenuEvent;
};

// Object instance structure
struct _jc_javax_swing_event_MenuEvent$object {
	_jc_javax_swing_event_MenuEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_MenuEvent$vtype	*vtype;
	_jc_javax_swing_event_MenuEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_MenuEvent$vtype _jc_javax_swing_event_MenuEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_MenuEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_MenuEvent$class_object;

#endif	/* _JC_javax_swing_event_MenuEvent_H_ */

==> jc-1.4.6.tar.gz: javax/swing/event/MenuEvent.h <==
// public class javax.swing.event.MenuEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class af163240253878eb javax_swing_event_MenuEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_MenuEvent_H_
#define _JC_javax_swing_event_MenuEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_swing_event_MenuEvent$sub_refs	_jc_javax_swing_event_MenuEvent$sub_refs;
typedef struct _jc_javax_swing_event_MenuEvent$sub_nonrefs	_jc_javax_swing_event_MenuEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_MenuEvent$refs	_jc_javax_swing_event_MenuEvent$refs;
typedef struct _jc_javax_swing_event_MenuEvent$nonrefs	_jc_javax_swing_event_MenuEvent$nonrefs;
typedef struct _jc_javax_swing_event_MenuEvent$object	_jc_javax_swing_event_MenuEvent$object;

typedef const struct _jc_javax_swing_event_MenuEvent$vmethods	_jc_javax_swing_event_MenuEvent$vmethods;
typedef const struct _jc_javax_swing_event_MenuEvent$vtable	_jc_javax_swing_event_MenuEvent$vtable;
typedef const struct _jc_javax_swing_event_MenuEvent$vtype	_jc_javax_swing_event_MenuEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_MenuEvent$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_javax_swing_event_MenuEvent$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_event_MenuEvent$vmethods {
};

// Vtable
struct _jc_javax_swing_event_MenuEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_MenuEvent$vmethods	javax_swing_event_MenuEvent;
};

// Vtype
struct _jc_javax_swing_event_MenuEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_MenuEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_MenuEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_MenuEvent$refs {
    _jc_javax_swing_event_MenuEvent$sub_refs	javax_swing_event_MenuEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_MenuEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_MenuEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_MenuEvent$sub_nonrefs	javax_swing_event_MenuEvent;
};

// Object instance structure
struct _jc_javax_swing_event_MenuEvent$object {
	_jc_javax_swing_event_MenuEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_MenuEvent$vtype	*vtype;
	_jc_javax_swing_event_MenuEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_MenuEvent$vtype _jc_javax_swing_event_MenuEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_MenuEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_MenuEvent$class_object;

#endif	/* _JC_javax_swing_event_MenuEvent_H_ */
